# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof_empty.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Nothing",
    "MaybeNothing",
    "Test",
)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Nothing(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False)
class MaybeNothing(betterproto.Message):
    """ """

    sometimes: str = betterproto.string_field(42)
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    nothing: "Nothing" = betterproto.message_field(1, group="empty")
    """
    
    """

    maybe1: "MaybeNothing" = betterproto.message_field(2, group="empty")
    """
    
    """

    maybe2: "MaybeNothing" = betterproto.message_field(3, group="empty")
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes_response.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Input",
    "TestStub",
    "TestBase",
)


from dataclasses import dataclass
from typing import (
    TYPE_CHECKING,
    Dict,
    Optional,
)

import grpclib

import betterproto_fw
from betterproto_fw.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto_fw.grpc.grpclib_client import MetadataLike


@dataclass(eq=False, repr=False)
class Input(betterproto_fw.Message):
    """ """

    pass


class TestStub(betterproto_fw.ServiceStub):
    """Tests that wrapped values can be used directly as return values"""

    async def get_double(
        self,
        input: "Input",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_fw_lib_google_protobuf.DoubleValue":
        """ """

        return await self._unary_unary(
            "/googletypes_response.Test/GetDouble",
            input,
            betterproto_fw_lib_google_protobuf.DoubleValue,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_float(
        self,
        input: "Input",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_fw_lib_google_protobuf.FloatValue":
        """ """

        return await self._unary_unary(
            "/googletypes_response.Test/GetFloat",
            input,
            betterproto_fw_lib_google_protobuf.FloatValue,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_int64(
        self,
        input: "Input",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_fw_lib_google_protobuf.Int64Value":
        """ """

        return await self._unary_unary(
            "/googletypes_response.Test/GetInt64",
            input,
            betterproto_fw_lib_google_protobuf.Int64Value,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_u_int64(
        self,
        input: "Input",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_fw_lib_google_protobuf.UInt64Value":
        """ """

        return await self._unary_unary(
            "/googletypes_response.Test/GetUInt64",
            input,
            betterproto_fw_lib_google_protobuf.UInt64Value,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_int32(
        self,
        input: "Input",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_fw_lib_google_protobuf.Int32Value":
        """ """

        return await self._unary_unary(
            "/googletypes_response.Test/GetInt32",
            input,
            betterproto_fw_lib_google_protobuf.Int32Value,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_u_int32(
        self,
        input: "Input",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_fw_lib_google_protobuf.UInt32Value":
        """ """

        return await self._unary_unary(
            "/googletypes_response.Test/GetUInt32",
            input,
            betterproto_fw_lib_google_protobuf.UInt32Value,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_bool(
        self,
        input: "Input",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_fw_lib_google_protobuf.BoolValue":
        """ """

        return await self._unary_unary(
            "/googletypes_response.Test/GetBool",
            input,
            betterproto_fw_lib_google_protobuf.BoolValue,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_string(
        self,
        input: "Input",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_fw_lib_google_protobuf.StringValue":
        """ """

        return await self._unary_unary(
            "/googletypes_response.Test/GetString",
            input,
            betterproto_fw_lib_google_protobuf.StringValue,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_bytes(
        self,
        input: "Input",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_fw_lib_google_protobuf.BytesValue":
        """ """

        return await self._unary_unary(
            "/googletypes_response.Test/GetBytes",
            input,
            betterproto_fw_lib_google_protobuf.BytesValue,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


import betterproto_fw.lib.google.protobuf as betterproto_fw_lib_google_protobuf


class TestBase(ServiceBase):
    """Tests that wrapped values can be used directly as return values"""

    async def get_double(
        self, input: "Input"
    ) -> "betterproto_fw_lib_google_protobuf.DoubleValue":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_float(
        self, input: "Input"
    ) -> "betterproto_fw_lib_google_protobuf.FloatValue":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_int64(
        self, input: "Input"
    ) -> "betterproto_fw_lib_google_protobuf.Int64Value":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_u_int64(
        self, input: "Input"
    ) -> "betterproto_fw_lib_google_protobuf.UInt64Value":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_int32(
        self, input: "Input"
    ) -> "betterproto_fw_lib_google_protobuf.Int32Value":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_u_int32(
        self, input: "Input"
    ) -> "betterproto_fw_lib_google_protobuf.UInt32Value":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_bool(
        self, input: "Input"
    ) -> "betterproto_fw_lib_google_protobuf.BoolValue":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_string(
        self, input: "Input"
    ) -> "betterproto_fw_lib_google_protobuf.StringValue":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_bytes(
        self, input: "Input"
    ) -> "betterproto_fw_lib_google_protobuf.BytesValue":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_get_double(
        self,
        stream: "grpclib.server.Stream[Input, betterproto_fw_lib_google_protobuf.DoubleValue]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_double(request)
        await stream.send_message(response)

    async def __rpc_get_float(
        self,
        stream: "grpclib.server.Stream[Input, betterproto_fw_lib_google_protobuf.FloatValue]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_float(request)
        await stream.send_message(response)

    async def __rpc_get_int64(
        self,
        stream: "grpclib.server.Stream[Input, betterproto_fw_lib_google_protobuf.Int64Value]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_int64(request)
        await stream.send_message(response)

    async def __rpc_get_u_int64(
        self,
        stream: "grpclib.server.Stream[Input, betterproto_fw_lib_google_protobuf.UInt64Value]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_u_int64(request)
        await stream.send_message(response)

    async def __rpc_get_int32(
        self,
        stream: "grpclib.server.Stream[Input, betterproto_fw_lib_google_protobuf.Int32Value]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_int32(request)
        await stream.send_message(response)

    async def __rpc_get_u_int32(
        self,
        stream: "grpclib.server.Stream[Input, betterproto_fw_lib_google_protobuf.UInt32Value]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_u_int32(request)
        await stream.send_message(response)

    async def __rpc_get_bool(
        self,
        stream: "grpclib.server.Stream[Input, betterproto_fw_lib_google_protobuf.BoolValue]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_bool(request)
        await stream.send_message(response)

    async def __rpc_get_string(
        self,
        stream: "grpclib.server.Stream[Input, betterproto_fw_lib_google_protobuf.StringValue]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_string(request)
        await stream.send_message(response)

    async def __rpc_get_bytes(
        self,
        stream: "grpclib.server.Stream[Input, betterproto_fw_lib_google_protobuf.BytesValue]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_bytes(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/googletypes_response.Test/GetDouble": grpclib.const.Handler(
                self.__rpc_get_double,
                grpclib.const.Cardinality.UNARY_UNARY,
                Input,
                betterproto_fw_lib_google_protobuf.DoubleValue,
            ),
            "/googletypes_response.Test/GetFloat": grpclib.const.Handler(
                self.__rpc_get_float,
                grpclib.const.Cardinality.UNARY_UNARY,
                Input,
                betterproto_fw_lib_google_protobuf.FloatValue,
            ),
            "/googletypes_response.Test/GetInt64": grpclib.const.Handler(
                self.__rpc_get_int64,
                grpclib.const.Cardinality.UNARY_UNARY,
                Input,
                betterproto_fw_lib_google_protobuf.Int64Value,
            ),
            "/googletypes_response.Test/GetUInt64": grpclib.const.Handler(
                self.__rpc_get_u_int64,
                grpclib.const.Cardinality.UNARY_UNARY,
                Input,
                betterproto_fw_lib_google_protobuf.UInt64Value,
            ),
            "/googletypes_response.Test/GetInt32": grpclib.const.Handler(
                self.__rpc_get_int32,
                grpclib.const.Cardinality.UNARY_UNARY,
                Input,
                betterproto_fw_lib_google_protobuf.Int32Value,
            ),
            "/googletypes_response.Test/GetUInt32": grpclib.const.Handler(
                self.__rpc_get_u_int32,
                grpclib.const.Cardinality.UNARY_UNARY,
                Input,
                betterproto_fw_lib_google_protobuf.UInt32Value,
            ),
            "/googletypes_response.Test/GetBool": grpclib.const.Handler(
                self.__rpc_get_bool,
                grpclib.const.Cardinality.UNARY_UNARY,
                Input,
                betterproto_fw_lib_google_protobuf.BoolValue,
            ),
            "/googletypes_response.Test/GetString": grpclib.const.Handler(
                self.__rpc_get_string,
                grpclib.const.Cardinality.UNARY_UNARY,
                Input,
                betterproto_fw_lib_google_protobuf.StringValue,
            ),
            "/googletypes_response.Test/GetBytes": grpclib.const.Handler(
                self.__rpc_get_bytes,
                grpclib.const.Cardinality.UNARY_UNARY,
                Input,
                betterproto_fw_lib_google_protobuf.BytesValue,
            ),
        }



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import messages_pb2 as messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12(service_separate_packages.things.service\x1a\x0emessages.proto2\xb7\x04\n\x04Test\x12\x80\x01\n\x07\x44oThing\x12\x39.service_separate_packages.things.messages.DoThingRequest\x1a:.service_separate_packages.things.messages.DoThingResponse\x12\x87\x01\n\x0c\x44oManyThings\x12\x39.service_separate_packages.things.messages.DoThingRequest\x1a:.service_separate_packages.things.messages.DoThingResponse(\x01\x12\x8d\x01\n\x10GetThingVersions\x12:.service_separate_packages.things.messages.GetThingRequest\x1a;.service_separate_packages.things.messages.GetThingResponse0\x01\x12\x91\x01\n\x12GetDifferentThings\x12:.service_separate_packages.things.messages.GetThingRequest\x1a;.service_separate_packages.things.messages.GetThingResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=76
  _globals['_TEST']._serialized_end=643
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: nested2.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "GamePlayerRace",
    "Game",
    "GamePlayer",
    "Test",
)


from dataclasses import dataclass

import betterproto_fw


class GamePlayerRace(betterproto_fw.Enum):
    """ """

    human = 0
    """
    
    """

    orc = 1
    """
    
    """


@dataclass(eq=False, repr=False)
class Game(betterproto_fw.Message):
    """ """

    pass


@dataclass(eq=False, repr=False)
class GamePlayer(betterproto_fw.Message):
    """ """

    pass


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    game: "Game" = betterproto_fw.message_field(1)
    """
    
    """

    game_player: "GamePlayer" = betterproto_fw.message_field(2)
    """
    
    """

    game_player_race: "GamePlayerRace" = betterproto_fw.enum_field(3)
    """
    
    """

    weapon: "equipment.Weapon" = betterproto_fw.message_field(4)
    """
    
    """


from . import equipment



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto3_field_presence.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proto3_field_presence.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bproto3_field_presence.proto\x12\x15proto3_field_presence\x1a\x1fgoogle/protobuf/timestamp.proto\"\x19\n\tInnerTest\x12\x0c\n\x04test\x18\x01 \x01(\t\"\xf3\x02\n\x04Test\x12\x12\n\x05test1\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05test2\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x12\n\x05test3\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05test4\x18\x04 \x01(\x0cH\x03\x88\x01\x01\x12\x34\n\x05test5\x18\x05 \x01(\x0b\x32 .proto3_field_presence.InnerTestH\x04\x88\x01\x01\x12\x33\n\x05test6\x18\x06 \x01(\x0e\x32\x1f.proto3_field_presence.TestEnumH\x05\x88\x01\x01\x12\x12\n\x05test7\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x12\n\x05test8\x18\x08 \x01(\x02H\x07\x88\x01\x01\x12.\n\x05test9\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x42\x08\n\x06_test1B\x08\n\x06_test2B\x08\n\x06_test3B\x08\n\x06_test4B\x08\n\x06_test5B\x08\n\x06_test6B\x08\n\x06_test7B\x08\n\x06_test8B\x08\n\x06_test9*\x18\n\x08TestEnum\x12\x05\n\x01\x41\x10\x00\x12\x05\n\x01\x42\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto3_field_presence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TESTENUM']._serialized_start=488
  _globals['_TESTENUM']._serialized_end=512
  _globals['_INNERTEST']._serialized_start=87
  _globals['_INNERTEST']._serialized_end=112
  _globals['_TEST']._serialized_start=115
  _globals['_TEST']._serialized_end=486
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof_default_value_serialization.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Message",
    "NestedMessage",
    "Test",
)


from datetime import datetime, timedelta
from typing import (
    Optional,
)

from pydantic import model_validator
from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Message(betterproto_fw.Message):
    """ """

    value: int = betterproto_fw.int64_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class NestedMessage(betterproto_fw.Message):
    """ """

    id: int = betterproto_fw.int64_field(1)
    """
    
    """

    wrapped_message_value: Optional["Message"] = betterproto_fw.message_field(
        2, optional=True, group="value_type"
    )
    """
    
    """

    @model_validator(mode="after")
    def check_oneof(cls, values):
        return cls._validate_field_groups(values)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    bool_value: Optional[bool] = betterproto_fw.bool_field(
        1, optional=True, group="value_type"
    )
    """
    
    """

    int64_value: Optional[int] = betterproto_fw.int64_field(
        2, optional=True, group="value_type"
    )
    """
    
    """

    timestamp_value: Optional[datetime] = betterproto_fw.message_field(
        3, optional=True, group="value_type"
    )
    """
    
    """

    duration_value: Optional[timedelta] = betterproto_fw.message_field(
        4, optional=True, group="value_type"
    )
    """
    
    """

    wrapped_message_value: Optional["Message"] = betterproto_fw.message_field(
        5, optional=True, group="value_type"
    )
    """
    
    """

    wrapped_nested_message_value: Optional["NestedMessage"] = (
        betterproto_fw.message_field(6, optional=True, group="value_type")
    )
    """
    
    """

    wrapped_bool_value: Optional[Optional[bool]] = betterproto_fw.message_field(
        7, wraps=betterproto_fw.TYPE_BOOL, optional=True, group="value_type"
    )
    """
    
    """

    @model_validator(mode="after")
    def check_oneof(cls, values):
        return cls._validate_field_groups(values)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: child.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """Verify that we can import root message from child package"""

    message: "__import_root_package_from_child__.RootMessage" = (
        betterproto.message_field(1)
    )
    """
    
    """


from ... import import_root_package_from_child as __import_root_package_from_child__



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: oneof_default_value_serialization.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'oneof_default_value_serialization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'oneof_default_value_serialization.proto\x12!oneof_default_value_serialization\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x18\n\x07Message\x12\r\n\x05value\x18\x01 \x01(\x03\"v\n\rNestedMessage\x12\n\n\x02id\x18\x01 \x01(\x03\x12K\n\x15wrapped_message_value\x18\x02 \x01(\x0b\x32*.oneof_default_value_serialization.MessageH\x00\x42\x0c\n\nvalue_type\"\x8e\x03\n\x04Test\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x02 \x01(\x03H\x00\x12\x35\n\x0ftimestamp_value\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x33\n\x0e\x64uration_value\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12K\n\x15wrapped_message_value\x18\x05 \x01(\x0b\x32*.oneof_default_value_serialization.MessageH\x00\x12X\n\x1cwrapped_nested_message_value\x18\x06 \x01(\x0b\x32\x30.oneof_default_value_serialization.NestedMessageH\x00\x12\x38\n\x12wrapped_bool_value\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x42\x0c\n\nvalue_typeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oneof_default_value_serialization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MESSAGE']._serialized_start=175
  _globals['_MESSAGE']._serialized_end=199
  _globals['_NESTEDMESSAGE']._serialized_start=201
  _globals['_NESTEDMESSAGE']._serialized_end=319
  _globals['_TEST']._serialized_start=322
  _globals['_TEST']._serialized_end=720
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: googletypes_service_returns_googletype.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'googletypes_service_returns_googletype.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,googletypes_service_returns_googletype.proto\x12&googletypes_service_returns_googletype\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x10\n\x0eRequestMessage2\x80\x03\n\x04Test\x12Z\n\x08GetEmpty\x12\x36.googletypes_service_returns_googletype.RequestMessage\x1a\x16.google.protobuf.Empty\x12\\\n\tGetStruct\x12\x36.googletypes_service_returns_googletype.RequestMessage\x1a\x17.google.protobuf.Struct\x12\x62\n\x0cGetListValue\x12\x36.googletypes_service_returns_googletype.RequestMessage\x1a\x1a.google.protobuf.ListValue\x12Z\n\x08GetValue\x12\x36.googletypes_service_returns_googletype.RequestMessage\x1a\x16.google.protobuf.Valueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'googletypes_service_returns_googletype_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REQUESTMESSAGE']._serialized_start=147
  _globals['_REQUESTMESSAGE']._serialized_end=163
  _globals['_TEST']._serialized_start=166
  _globals['_TEST']._serialized_end=550
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: empty_service.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "TestStub",
    "TestBase",
)


from typing import (
    Dict,
)

import grpclib

import betterproto_fw
from betterproto_fw.grpc.grpclib_server import ServiceBase


class TestStub(betterproto_fw.ServiceStub):
    """ """


class TestBase(ServiceBase):
    """ """

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {}



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: double.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    count: float = betterproto.double_field(1)
    """
    
    """



import pytest

from betterproto.plugin.typing_compiler import (
    DirectImportTypingCompiler,
    NoTyping310TypingCompiler,
    TypingImportTypingCompiler,
)


def test_direct_import_typing_compiler():
    compiler = DirectImportTypingCompiler()
    assert compiler.imports() == {}
    assert compiler.optional("str") == "Optional[str]"
    assert compiler.imports() == {"typing": {"Optional"}}
    assert compiler.list("str") == "List[str]"
    assert compiler.imports() == {"typing": {"Optional", "List"}}
    assert compiler.dict("str", "int") == "Dict[str, int]"
    assert compiler.imports() == {"typing": {"Optional", "List", "Dict"}}
    assert compiler.union("str", "int") == "Union[str, int]"
    assert compiler.imports() == {"typing": {"Optional", "List", "Dict", "Union"}}
    assert compiler.iterable("str") == "Iterable[str]"
    assert compiler.imports() == {
        "typing": {"Optional", "List", "Dict", "Union", "Iterable"}
    }
    assert compiler.async_iterable("str") == "AsyncIterable[str]"
    assert compiler.imports() == {
        "typing": {"Optional", "List", "Dict", "Union", "Iterable", "AsyncIterable"}
    }
    assert compiler.async_iterator("str") == "AsyncIterator[str]"
    assert compiler.imports() == {
        "typing": {
            "Optional",
            "List",
            "Dict",
            "Union",
            "Iterable",
            "AsyncIterable",
            "AsyncIterator",
        }
    }


def test_typing_import_typing_compiler():
    compiler = TypingImportTypingCompiler()
    assert compiler.imports() == {}
    assert compiler.optional("str") == "typing.Optional[str]"
    assert compiler.imports() == {"typing": None}
    assert compiler.list("str") == "typing.List[str]"
    assert compiler.imports() == {"typing": None}
    assert compiler.dict("str", "int") == "typing.Dict[str, int]"
    assert compiler.imports() == {"typing": None}
    assert compiler.union("str", "int") == "typing.Union[str, int]"
    assert compiler.imports() == {"typing": None}
    assert compiler.iterable("str") == "typing.Iterable[str]"
    assert compiler.imports() == {"typing": None}
    assert compiler.async_iterable("str") == "typing.AsyncIterable[str]"
    assert compiler.imports() == {"typing": None}
    assert compiler.async_iterator("str") == "typing.AsyncIterator[str]"
    assert compiler.imports() == {"typing": None}


def test_no_typing_311_typing_compiler():
    compiler = NoTyping310TypingCompiler()
    assert compiler.imports() == {}
    assert compiler.optional("str") == '"str | None"'
    assert compiler.imports() == {}
    assert compiler.list("str") == '"list[str]"'
    assert compiler.imports() == {}
    assert compiler.dict("str", "int") == '"dict[str, int]"'
    assert compiler.imports() == {}
    assert compiler.union("str", "int") == '"str | int"'
    assert compiler.imports() == {}
    assert compiler.iterable("str") == '"Iterable[str]"'
    assert compiler.async_iterable("str") == '"AsyncIterable[str]"'
    assert compiler.async_iterator("str") == '"AsyncIterator[str]"'
    assert compiler.imports() == {
        "collections.abc": {"Iterable", "AsyncIterable", "AsyncIterator"}
    }



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: nested.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "TestMsg",
    "Test",
    "TestNested",
    "Sibling",
)


from dataclasses import dataclass

import betterproto_fw


class TestMsg(betterproto_fw.Enum):
    """This is the nested enum."""

    NONE = 0
    """
    
    """

    THIS = 1
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """A test message with a nested message inside of it."""

    nested: "TestNested" = betterproto_fw.message_field(1)
    """
    
    """

    sibling: "Sibling" = betterproto_fw.message_field(2)
    """
    
    """

    sibling2: "Sibling" = betterproto_fw.message_field(3)
    """
    
    """

    msg: "TestMsg" = betterproto_fw.enum_field(4)
    """
    
    """


@dataclass(eq=False, repr=False)
class TestNested(betterproto_fw.Message):
    """This is the nested type."""

    count: int = betterproto_fw.int32_field(1)
    """Stores a simple counter."""


@dataclass(eq=False, repr=False)
class Sibling(betterproto_fw.Message):
    """ """

    foo: int = betterproto_fw.int32_field(1)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_parent_package_from_child.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """
    Tests generated imports when a message refers to a message defined in its parent package
    """

    message_implicit: "__parent__.ParentPackageMessage" = betterproto_fw.message_field(
        1
    )
    """
    
    """

    message_explicit: "__parent__.ParentPackageMessage" = betterproto_fw.message_field(
        2
    )
    """
    
    """


from ... import parent as __parent__



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: regression_387.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "ParentElement",
)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    id: int = betterproto.uint64_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class ParentElement(betterproto.Message):
    """ """

    name: str = betterproto.string_field(1)
    """
    
    """

    elems: List["Test"] = betterproto.message_field(2)
    """
    
    """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: oneof_empty.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'oneof_empty.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11oneof_empty.proto\x12\x0boneof_empty\"\t\n\x07Nothing\"!\n\x0cMaybeNothing\x12\x11\n\tsometimes\x18* \x01(\t\"\x92\x01\n\x04Test\x12\'\n\x07nothing\x18\x01 \x01(\x0b\x32\x14.oneof_empty.NothingH\x00\x12+\n\x06maybe1\x18\x02 \x01(\x0b\x32\x19.oneof_empty.MaybeNothingH\x00\x12+\n\x06maybe2\x18\x03 \x01(\x0b\x32\x19.oneof_empty.MaybeNothingH\x00\x42\x07\n\x05\x65mptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oneof_empty_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NOTHING']._serialized_start=34
  _globals['_NOTHING']._serialized_end=43
  _globals['_MAYBENOTHING']._serialized_start=45
  _globals['_MAYBENOTHING']._serialized_end=78
  _globals['_TEST']._serialized_start=81
  _globals['_TEST']._serialized_end=227
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes_response_embedded.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Input",
    "Output",
    "TestStub",
    "TestBase",
)


from dataclasses import dataclass
from typing import (
    TYPE_CHECKING,
    Dict,
    Optional,
)

import grpclib

import betterproto_fw
from betterproto_fw.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto_fw.grpc.grpclib_client import MetadataLike


@dataclass(eq=False, repr=False)
class Input(betterproto_fw.Message):
    """ """

    pass


@dataclass(eq=False, repr=False)
class Output(betterproto_fw.Message):
    """ """

    double_value: Optional[float] = betterproto_fw.message_field(
        1, wraps=betterproto_fw.TYPE_DOUBLE
    )
    """
    
    """

    float_value: Optional[float] = betterproto_fw.message_field(
        2, wraps=betterproto_fw.TYPE_FLOAT
    )
    """
    
    """

    int64_value: Optional[int] = betterproto_fw.message_field(
        3, wraps=betterproto_fw.TYPE_INT64
    )
    """
    
    """

    uint64_value: Optional[int] = betterproto_fw.message_field(
        4, wraps=betterproto_fw.TYPE_UINT64
    )
    """
    
    """

    int32_value: Optional[int] = betterproto_fw.message_field(
        5, wraps=betterproto_fw.TYPE_INT32
    )
    """
    
    """

    uint32_value: Optional[int] = betterproto_fw.message_field(
        6, wraps=betterproto_fw.TYPE_UINT32
    )
    """
    
    """

    bool_value: Optional[bool] = betterproto_fw.message_field(
        7, wraps=betterproto_fw.TYPE_BOOL
    )
    """
    
    """

    string_value: Optional[str] = betterproto_fw.message_field(
        8, wraps=betterproto_fw.TYPE_STRING
    )
    """
    
    """

    bytes_value: Optional[bytes] = betterproto_fw.message_field(
        9, wraps=betterproto_fw.TYPE_BYTES
    )
    """
    
    """


class TestStub(betterproto_fw.ServiceStub):
    """Tests that wrapped values are supported as part of output message"""

    async def get_output(
        self,
        input: "Input",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Output":
        """ """

        return await self._unary_unary(
            "/googletypes_response_embedded.Test/getOutput",
            input,
            Output,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class TestBase(ServiceBase):
    """Tests that wrapped values are supported as part of output message"""

    async def get_output(self, input: "Input") -> "Output":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_get_output(
        self, stream: "grpclib.server.Stream[Input, Output]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.get_output(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/googletypes_response_embedded.Test/getOutput": grpclib.const.Handler(
                self.__rpc_get_output,
                grpclib.const.Cardinality.UNARY_UNARY,
                Input,
                Output,
            ),
        }



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "MixedDrink",
    "Test",
)


from typing import (
    Optional,
)

from pydantic import model_validator
from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class MixedDrink(betterproto_fw.Message):
    """ """

    shots: int = betterproto_fw.int32_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    pitied: Optional[int] = betterproto_fw.int32_field(1, optional=True, group="foo")
    """
    
    """

    pitier: Optional[str] = betterproto_fw.string_field(2, optional=True, group="foo")
    """
    
    """

    just_a_regular_field: int = betterproto_fw.int32_field(3)
    """
    
    """

    drinks: Optional[int] = betterproto_fw.int32_field(11, optional=True, group="bar")
    """
    
    """

    bar_name: Optional[str] = betterproto_fw.string_field(
        12, optional=True, group="bar"
    )
    """
    
    """

    mixed_drink: Optional["MixedDrink"] = betterproto_fw.message_field(
        13, optional=True, group="bar"
    )
    """
    
    """

    @model_validator(mode="after")
    def check_oneof(cls, values):
        return cls._validate_field_groups(values)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_parent_package_from_child.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """
    Tests generated imports when a message refers to a message defined in its parent package
    """

    message_implicit: "__parent__.ParentPackageMessage" = betterproto.message_field(1)
    """
    
    """

    message_explicit: "__parent__.ParentPackageMessage" = betterproto.message_field(2)
    """
    
    """


from ... import parent as __parent__



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: field_name_identical_to_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'field_name_identical_to_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"field_name_identical_to_type.proto\x12\x1c\x66ield_name_identical_to_type\"L\n\x04Test\x12\x0b\n\x03int\x18\x01 \x01(\x05\x12\r\n\x05\x66loat\x18\x02 \x01(\x02\x12\x0b\n\x03str\x18\x03 \x01(\t\x12\r\n\x05\x62ytes\x18\x04 \x01(\x0c\x12\x0c\n\x04\x62ool\x18\x05 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'field_name_identical_to_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=68
  _globals['_TEST']._serialized_end=144
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_root_sibling.proto, sibling.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "SiblingMessage",
    "Test",
)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class SiblingMessage(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """
    Tests generated imports when a message in the root package refers to another message in the root package
    """

    sibling: "SiblingMessage" = betterproto.message_field(1)
    """
    
    """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: googletypes.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'googletypes.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11googletypes.proto\x12\x0bgoogletypes\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xdd\x01\n\x04Test\x12)\n\x05maybe\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12&\n\x02ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12.\n\timportant\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12%\n\x05\x65mpty\x18\x05 \x01(\x0b\x32\x16.google.protobuf.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'googletypes_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=161
  _globals['_TEST']._serialized_end=382
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: google_impl_behavior_equivalence.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Foo",
    "Test",
    "Spam",
    "Request",
    "Empty",
)


from dataclasses import dataclass
from datetime import datetime

import betterproto_fw


@dataclass(eq=False, repr=False)
class Foo(betterproto_fw.Message):
    """ """

    bar: int = betterproto_fw.int64_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    string: str = betterproto_fw.string_field(1, group="group")
    """
    
    """

    integer: int = betterproto_fw.int64_field(2, group="group")
    """
    
    """

    foo: "Foo" = betterproto_fw.message_field(3, group="group")
    """
    
    """


@dataclass(eq=False, repr=False)
class Spam(betterproto_fw.Message):
    """ """

    ts: datetime = betterproto_fw.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Request(betterproto_fw.Message):
    """ """

    foo: "Empty" = betterproto_fw.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Empty(betterproto_fw.Message):
    """ """

    pass



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: test.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """
    Tests that we can import from a package with a capital name, that looks like a nested type, but isn't.
    """

    message: "CapitalizedMessage" = betterproto_fw.message_field(1)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: signed.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    signed32: int = betterproto.sint32_field(1)
    """
    todo: rename fields after fixing bug where 'signed_32_positive' will map to 'signed_32Positive' as output json
    
     signed_32_positive
    """

    negative32: int = betterproto.sint32_field(2)
    """ signed_32_negative"""

    string64: int = betterproto.sint64_field(3)
    """ signed_64_positive"""

    negative64: int = betterproto.sint64_field(4)
    """ signed_64_negative"""



import os.path
import subprocess
import sys

from .module_validation import ModuleValidator


try:
    # betterproto[compiler] specific dependencies
    import jinja2
except ImportError as err:
    print(
        "\033[31m"
        f"Unable to import `{err.name}` from betterproto plugin! "
        "Please ensure that you've installed betterproto as "
        '`pip install "betterproto[compiler]"` so that compiler dependencies '
        "are included."
        "\033[0m"
    )
    raise SystemExit(1)

from .models import OutputTemplate


def outputfile_compiler(output_file: OutputTemplate) -> str:
    templates_folder = os.path.abspath(
        os.path.join(os.path.dirname(__file__), "..", "templates")
    )

    env = jinja2.Environment(
        trim_blocks=True,
        lstrip_blocks=True,
        loader=jinja2.FileSystemLoader(templates_folder),
        undefined=jinja2.StrictUndefined,
    )
    # Load the body first so we have a compleate list of imports needed.
    body_template = env.get_template("template.py.j2")
    header_template = env.get_template("header.py.j2")

    code = body_template.render(output_file=output_file)
    code = header_template.render(output_file=output_file) + code

    # Sort imports, delete unused ones
    code = subprocess.check_output(
        ["ruff", "check", "--select", "I,F401", "--fix", "--silent", "-"],
        input=code,
        encoding="utf-8",
    )

    # Format the code
    code = subprocess.check_output(
        ["ruff", "format", "-"], input=code, encoding="utf-8"
    )

    # Validate the generated code.
    validator = ModuleValidator(iter(code.splitlines()))
    if not validator.validate():
        message_builder = ["[WARNING]: Generated code has collisions in the module:"]
        for collision, lines in validator.collisions.items():
            message_builder.append(f'  "{collision}" on lines:')
            for num, line in lines:
                message_builder.append(f"    {num}:{line}")
        print("\n".join(message_builder), file=sys.stderr)
    return code



import ast
import inspect


def check(generated_doc: str, type: str) -> None:
    assert f"Documentation of {type} 1" in generated_doc
    assert "other line 1" in generated_doc
    assert f"Documentation of {type} 2" in generated_doc
    assert "other line 2" in generated_doc
    assert f"Documentation of {type} 3" in generated_doc


def test_documentation() -> None:
    from .output_betterproto.documentation import (
        Enum,
        ServiceBase,
        ServiceStub,
        Test,
    )

    check(Test.__doc__, "message")

    source = inspect.getsource(Test)
    tree = ast.parse(source)
    check(tree.body[0].body[2].value.value, "field")

    check(Enum.__doc__, "enum")

    source = inspect.getsource(Enum)
    tree = ast.parse(source)
    check(tree.body[0].body[2].value.value, "variant")

    check(ServiceBase.__doc__, "service")
    check(ServiceBase.get.__doc__, "method")

    check(ServiceStub.__doc__, "service")
    check(ServiceStub.get.__doc__, "method")



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes_request.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Input",
    "TestStub",
    "TestBase",
)


from dataclasses import dataclass
from typing import (
    TYPE_CHECKING,
    Dict,
    Optional,
)

import grpclib

import betterproto
from betterproto.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto.grpc.grpclib_client import MetadataLike


@dataclass(eq=False, repr=False)
class Input(betterproto.Message):
    """ """

    pass


class TestStub(betterproto.ServiceStub):
    """Tests that google types can be used as params"""

    async def send_double(
        self,
        betterproto_lib_google_protobuf_double_value: "betterproto_lib_google_protobuf.DoubleValue",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendDouble",
            betterproto_lib_google_protobuf_double_value,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_float(
        self,
        betterproto_lib_google_protobuf_float_value: "betterproto_lib_google_protobuf.FloatValue",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendFloat",
            betterproto_lib_google_protobuf_float_value,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_int64(
        self,
        betterproto_lib_google_protobuf_int64_value: "betterproto_lib_google_protobuf.Int64Value",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendInt64",
            betterproto_lib_google_protobuf_int64_value,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_u_int64(
        self,
        betterproto_lib_google_protobuf_u_int64_value: "betterproto_lib_google_protobuf.UInt64Value",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendUInt64",
            betterproto_lib_google_protobuf_u_int64_value,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_int32(
        self,
        betterproto_lib_google_protobuf_int32_value: "betterproto_lib_google_protobuf.Int32Value",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendInt32",
            betterproto_lib_google_protobuf_int32_value,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_u_int32(
        self,
        betterproto_lib_google_protobuf_u_int32_value: "betterproto_lib_google_protobuf.UInt32Value",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendUInt32",
            betterproto_lib_google_protobuf_u_int32_value,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_bool(
        self,
        betterproto_lib_google_protobuf_bool_value: "betterproto_lib_google_protobuf.BoolValue",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendBool",
            betterproto_lib_google_protobuf_bool_value,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_string(
        self,
        betterproto_lib_google_protobuf_string_value: "betterproto_lib_google_protobuf.StringValue",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendString",
            betterproto_lib_google_protobuf_string_value,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_bytes(
        self,
        betterproto_lib_google_protobuf_bytes_value: "betterproto_lib_google_protobuf.BytesValue",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendBytes",
            betterproto_lib_google_protobuf_bytes_value,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_datetime(
        self,
        betterproto_lib_google_protobuf_timestamp: "betterproto_lib_google_protobuf.Timestamp",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendDatetime",
            betterproto_lib_google_protobuf_timestamp,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_timedelta(
        self,
        betterproto_lib_google_protobuf_duration: "betterproto_lib_google_protobuf.Duration",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendTimedelta",
            betterproto_lib_google_protobuf_duration,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def send_empty(
        self,
        betterproto_lib_google_protobuf_empty: "betterproto_lib_google_protobuf.Empty",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Input":
        """ """

        return await self._unary_unary(
            "/googletypes_request.Test/SendEmpty",
            betterproto_lib_google_protobuf_empty,
            Input,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


import betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


class TestBase(ServiceBase):
    """Tests that google types can be used as params"""

    async def send_double(
        self,
        betterproto_lib_google_protobuf_double_value: "betterproto_lib_google_protobuf.DoubleValue",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_float(
        self,
        betterproto_lib_google_protobuf_float_value: "betterproto_lib_google_protobuf.FloatValue",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_int64(
        self,
        betterproto_lib_google_protobuf_int64_value: "betterproto_lib_google_protobuf.Int64Value",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_u_int64(
        self,
        betterproto_lib_google_protobuf_u_int64_value: "betterproto_lib_google_protobuf.UInt64Value",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_int32(
        self,
        betterproto_lib_google_protobuf_int32_value: "betterproto_lib_google_protobuf.Int32Value",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_u_int32(
        self,
        betterproto_lib_google_protobuf_u_int32_value: "betterproto_lib_google_protobuf.UInt32Value",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_bool(
        self,
        betterproto_lib_google_protobuf_bool_value: "betterproto_lib_google_protobuf.BoolValue",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_string(
        self,
        betterproto_lib_google_protobuf_string_value: "betterproto_lib_google_protobuf.StringValue",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_bytes(
        self,
        betterproto_lib_google_protobuf_bytes_value: "betterproto_lib_google_protobuf.BytesValue",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_datetime(
        self,
        betterproto_lib_google_protobuf_timestamp: "betterproto_lib_google_protobuf.Timestamp",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_timedelta(
        self,
        betterproto_lib_google_protobuf_duration: "betterproto_lib_google_protobuf.Duration",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def send_empty(
        self,
        betterproto_lib_google_protobuf_empty: "betterproto_lib_google_protobuf.Empty",
    ) -> "Input":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_send_double(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.DoubleValue, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_double(request)
        await stream.send_message(response)

    async def __rpc_send_float(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.FloatValue, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_float(request)
        await stream.send_message(response)

    async def __rpc_send_int64(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.Int64Value, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_int64(request)
        await stream.send_message(response)

    async def __rpc_send_u_int64(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.UInt64Value, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_u_int64(request)
        await stream.send_message(response)

    async def __rpc_send_int32(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.Int32Value, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_int32(request)
        await stream.send_message(response)

    async def __rpc_send_u_int32(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.UInt32Value, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_u_int32(request)
        await stream.send_message(response)

    async def __rpc_send_bool(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.BoolValue, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_bool(request)
        await stream.send_message(response)

    async def __rpc_send_string(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.StringValue, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_string(request)
        await stream.send_message(response)

    async def __rpc_send_bytes(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.BytesValue, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_bytes(request)
        await stream.send_message(response)

    async def __rpc_send_datetime(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.Timestamp, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_datetime(request)
        await stream.send_message(response)

    async def __rpc_send_timedelta(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.Duration, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_timedelta(request)
        await stream.send_message(response)

    async def __rpc_send_empty(
        self,
        stream: "grpclib.server.Stream[betterproto_lib_google_protobuf.Empty, Input]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send_empty(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/googletypes_request.Test/SendDouble": grpclib.const.Handler(
                self.__rpc_send_double,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.DoubleValue,
                Input,
            ),
            "/googletypes_request.Test/SendFloat": grpclib.const.Handler(
                self.__rpc_send_float,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.FloatValue,
                Input,
            ),
            "/googletypes_request.Test/SendInt64": grpclib.const.Handler(
                self.__rpc_send_int64,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.Int64Value,
                Input,
            ),
            "/googletypes_request.Test/SendUInt64": grpclib.const.Handler(
                self.__rpc_send_u_int64,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.UInt64Value,
                Input,
            ),
            "/googletypes_request.Test/SendInt32": grpclib.const.Handler(
                self.__rpc_send_int32,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.Int32Value,
                Input,
            ),
            "/googletypes_request.Test/SendUInt32": grpclib.const.Handler(
                self.__rpc_send_u_int32,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.UInt32Value,
                Input,
            ),
            "/googletypes_request.Test/SendBool": grpclib.const.Handler(
                self.__rpc_send_bool,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.BoolValue,
                Input,
            ),
            "/googletypes_request.Test/SendString": grpclib.const.Handler(
                self.__rpc_send_string,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.StringValue,
                Input,
            ),
            "/googletypes_request.Test/SendBytes": grpclib.const.Handler(
                self.__rpc_send_bytes,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.BytesValue,
                Input,
            ),
            "/googletypes_request.Test/SendDatetime": grpclib.const.Handler(
                self.__rpc_send_datetime,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.Timestamp,
                Input,
            ),
            "/googletypes_request.Test/SendTimedelta": grpclib.const.Handler(
                self.__rpc_send_timedelta,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.Duration,
                Input,
            ),
            "/googletypes_request.Test/SendEmpty": grpclib.const.Handler(
                self.__rpc_send_empty,
                grpclib.const.Cardinality.UNARY_UNARY,
                betterproto_lib_google_protobuf.Empty,
                Input,
            ),
        }



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: casing_message_field_uppercase.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'casing_message_field_uppercase.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$casing_message_field_uppercase.proto\x12\x1e\x63\x61sing_message_field_uppercase\"I\n\x04Test\x12\x11\n\tUPPERCASE\x18\x01 \x01(\x05\x12\x14\n\x0cUPPERCASE_V2\x18\x02 \x01(\x05\x12\x18\n\x10UPPER_CAMEL_CASE\x18\x03 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'casing_message_field_uppercase_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=72
  _globals['_TEST']._serialized_end=145
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: nested2.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "GamePlayerRace",
    "Game",
    "GamePlayer",
    "Test",
)


from pydantic.dataclasses import dataclass

import betterproto


class GamePlayerRace(betterproto.Enum):
    """ """

    human = 0
    """
    
    """

    orc = 1
    """
    
    """

    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type, _handler):
        from pydantic_core import core_schema

        return core_schema.int_schema(ge=0)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Game(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class GamePlayer(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    game: "Game" = betterproto.message_field(1)
    """
    
    """

    game_player: "GamePlayer" = betterproto.message_field(2)
    """
    
    """

    game_player_race: "GamePlayerRace" = betterproto.enum_field(3)
    """
    
    """

    weapon: "equipment.Weapon" = betterproto.message_field(4)
    """
    
    """


from . import equipment



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: deprecated.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'deprecated.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64\x65precated.proto\x12\ndeprecated\"?\n\x04Test\x12(\n\x07message\x18\x01 \x01(\x0b\x32\x13.deprecated.MessageB\x02\x18\x01\x12\r\n\x05value\x18\x02 \x01(\x05\"\x1c\n\x07Message\x12\r\n\x05value\x18\x01 \x01(\t:\x02\x18\x01\"\x07\n\x05\x45mpty2y\n\x0bTestService\x12,\n\x04\x66unc\x12\x11.deprecated.Empty\x1a\x11.deprecated.Empty\x12<\n\x0f\x64\x65precated_func\x12\x11.deprecated.Empty\x1a\x11.deprecated.Empty\"\x03\x88\x02\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deprecated_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST'].fields_by_name['message']._loaded_options = None
  _globals['_TEST'].fields_by_name['message']._serialized_options = b'\030\001'
  _globals['_MESSAGE']._loaded_options = None
  _globals['_MESSAGE']._serialized_options = b'\030\001'
  _globals['_TESTSERVICE'].methods_by_name['deprecated_func']._loaded_options = None
  _globals['_TESTSERVICE'].methods_by_name['deprecated_func']._serialized_options = b'\210\002\001'
  _globals['_TEST']._serialized_start=32
  _globals['_TEST']._serialized_end=95
  _globals['_MESSAGE']._serialized_start=97
  _globals['_MESSAGE']._serialized_end=125
  _globals['_EMPTY']._serialized_start=127
  _globals['_EMPTY']._serialized_end=134
  _globals['_TESTSERVICE']._serialized_start=136
  _globals['_TESTSERVICE']._serialized_end=257
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: entry.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "ExportEntry",
)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """
    This is a minimal example of a repeated message field that caused issues when
    checking whether a message is a map.

    During the check wheter a field is a "map", the string "entry" is added to
    the field name, checked against the type name and then further checks are
    made against the nested type of a parent message. In this edge-case, the
    first check would pass even though it shouldn't and that would cause an
    error because the parent type does not have a "nested_type" attribute.
    """

    export: List["ExportEntry"] = betterproto.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class ExportEntry(betterproto.Message):
    """ """

    name: str = betterproto.string_field(1)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: int32.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """Some documentation about the Test message."""

    positive: int = betterproto.int32_field(1)
    """Some documentation about the count."""

    negative: int = betterproto.int32_field(2)
    """
    
    """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: oneof.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'oneof.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0boneof.proto\x12\x05oneof\"\x1b\n\nMixedDrink\x12\r\n\x05shots\x18\x01 \x01(\x05\"\xa6\x01\n\x04Test\x12\x10\n\x06pitied\x18\x01 \x01(\x05H\x00\x12\x10\n\x06pitier\x18\x02 \x01(\tH\x00\x12\x1c\n\x14just_a_regular_field\x18\x03 \x01(\x05\x12\x10\n\x06\x64rinks\x18\x0b \x01(\x05H\x01\x12\x12\n\x08\x62\x61r_name\x18\x0c \x01(\tH\x01\x12(\n\x0bmixed_drink\x18\r \x01(\x0b\x32\x11.oneof.MixedDrinkH\x01\x42\x05\n\x03\x66ooB\x05\n\x03\x62\x61rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oneof_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MIXEDDRINK']._serialized_start=22
  _globals['_MIXEDDRINK']._serialized_end=49
  _globals['_TEST']._serialized_start=52
  _globals['_TEST']._serialized_end=218
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: googletypes_value.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'googletypes_value.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17googletypes_value.proto\x12\x11googletypes_value\x1a\x1cgoogle/protobuf/struct.proto\"\xce\x01\n\x04Test\x12&\n\x06value1\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\x12&\n\x06value2\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value\x12&\n\x06value3\x18\x03 \x01(\x0b\x32\x16.google.protobuf.Value\x12&\n\x06value4\x18\x04 \x01(\x0b\x32\x16.google.protobuf.Value\x12&\n\x06value5\x18\x05 \x01(\x0b\x32\x16.google.protobuf.Valueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'googletypes_value_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=77
  _globals['_TEST']._serialized_end=283
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes_value.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """
    Tests that fields of type google.protobuf.Value can contain arbitrary JSON-values.
    """

    value1: "betterproto_fw_lib_pydantic_google_protobuf.Value" = (
        betterproto_fw.message_field(1)
    )
    """
    
    """

    value2: "betterproto_fw_lib_pydantic_google_protobuf.Value" = (
        betterproto_fw.message_field(2)
    )
    """
    
    """

    value3: "betterproto_fw_lib_pydantic_google_protobuf.Value" = (
        betterproto_fw.message_field(3)
    )
    """
    
    """

    value4: "betterproto_fw_lib_pydantic_google_protobuf.Value" = (
        betterproto_fw.message_field(4)
    )
    """
    
    """

    value5: "betterproto_fw_lib_pydantic_google_protobuf.Value" = (
        betterproto_fw.message_field(5)
    )
    """
    
    """


import betterproto_fw.lib.pydantic.google.protobuf as betterproto_fw_lib_pydantic_google_protobuf



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: repeatedmessage.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "Sub",
)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    greetings: List["Sub"] = betterproto_fw.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Sub(betterproto_fw.Message):
    """ """

    greeting: str = betterproto_fw.string_field(1)
    """
    
    """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: casing.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'casing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63\x61sing.proto\x12\x06\x63\x61sing\"\x89\x01\n\x04Test\x12\x11\n\tcamelCase\x18\x01 \x01(\x05\x12#\n\nsnake_case\x18\x02 \x01(\x0e\x32\x0f.casing.my_enum\x12\x36\n\x12snake_case_message\x18\x03 \x01(\x0b\x32\x1a.casing.snake_case_message\x12\x11\n\tUPPERCASE\x18\x04 \x01(\x05\"\x14\n\x12snake_case_message*%\n\x07my_enum\x12\x08\n\x04ZERO\x10\x00\x12\x07\n\x03ONE\x10\x01\x12\x07\n\x03TWO\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'casing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MY_ENUM']._serialized_start=186
  _globals['_MY_ENUM']._serialized_end=223
  _globals['_TEST']._serialized_start=25
  _globals['_TEST']._serialized_end=162
  _globals['_SNAKE_CASE_MESSAGE']._serialized_start=89
  _globals['_SNAKE_CASE_MESSAGE']._serialized_end=109
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: example_service.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "ExampleRequest",
    "ExampleResponse",
    "TestStub",
    "TestBase",
)


from typing import (
    TYPE_CHECKING,
    AsyncIterable,
    AsyncIterator,
    Dict,
    Iterable,
    Optional,
    Union,
)

import grpclib
from pydantic.dataclasses import dataclass

import betterproto
from betterproto.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto.grpc.grpclib_client import MetadataLike


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class ExampleRequest(betterproto.Message):
    """ """

    example_string: str = betterproto.string_field(1)
    """
    
    """

    example_integer: int = betterproto.int64_field(2)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class ExampleResponse(betterproto.Message):
    """ """

    example_string: str = betterproto.string_field(1)
    """
    
    """

    example_integer: int = betterproto.int64_field(2)
    """
    
    """


class TestStub(betterproto.ServiceStub):
    """ """

    async def example_unary_unary(
        self,
        example_request: "ExampleRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "ExampleResponse":
        """ """

        return await self._unary_unary(
            "/example_service.Test/ExampleUnaryUnary",
            example_request,
            ExampleResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def example_unary_stream(
        self,
        example_request: "ExampleRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "AsyncIterator[ExampleResponse]":
        """ """

        async for response in self._unary_stream(
            "/example_service.Test/ExampleUnaryStream",
            example_request,
            ExampleResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        ):
            yield response

    async def example_stream_unary(
        self,
        example_request_iterator: "Union[AsyncIterable[ExampleRequest], Iterable[ExampleRequest]]",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "ExampleResponse":
        """ """

        return await self._stream_unary(
            "/example_service.Test/ExampleStreamUnary",
            example_request_iterator,
            ExampleRequest,
            ExampleResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def example_stream_stream(
        self,
        example_request_iterator: "Union[AsyncIterable[ExampleRequest], Iterable[ExampleRequest]]",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "AsyncIterator[ExampleResponse]":
        """ """

        async for response in self._stream_stream(
            "/example_service.Test/ExampleStreamStream",
            example_request_iterator,
            ExampleRequest,
            ExampleResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        ):
            yield response


class TestBase(ServiceBase):
    """ """

    async def example_unary_unary(
        self, example_request: "ExampleRequest"
    ) -> "ExampleResponse":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def example_unary_stream(
        self, example_request: "ExampleRequest"
    ) -> AsyncIterator[ExampleResponse]:
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)
        yield ExampleResponse()

    async def example_stream_unary(
        self, example_request_iterator: AsyncIterator[ExampleRequest]
    ) -> "ExampleResponse":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def example_stream_stream(
        self, example_request_iterator: AsyncIterator[ExampleRequest]
    ) -> AsyncIterator[ExampleResponse]:
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)
        yield ExampleResponse()

    async def __rpc_example_unary_unary(
        self, stream: "grpclib.server.Stream[ExampleRequest, ExampleResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.example_unary_unary(request)
        await stream.send_message(response)

    async def __rpc_example_unary_stream(
        self, stream: "grpclib.server.Stream[ExampleRequest, ExampleResponse]"
    ) -> None:
        request = await stream.recv_message()
        await self._call_rpc_handler_server_stream(
            self.example_unary_stream,
            stream,
            request,
        )

    async def __rpc_example_stream_unary(
        self, stream: "grpclib.server.Stream[ExampleRequest, ExampleResponse]"
    ) -> None:
        request = stream.__aiter__()
        response = await self.example_stream_unary(request)
        await stream.send_message(response)

    async def __rpc_example_stream_stream(
        self, stream: "grpclib.server.Stream[ExampleRequest, ExampleResponse]"
    ) -> None:
        request = stream.__aiter__()
        await self._call_rpc_handler_server_stream(
            self.example_stream_stream,
            stream,
            request,
        )

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/example_service.Test/ExampleUnaryUnary": grpclib.const.Handler(
                self.__rpc_example_unary_unary,
                grpclib.const.Cardinality.UNARY_UNARY,
                ExampleRequest,
                ExampleResponse,
            ),
            "/example_service.Test/ExampleUnaryStream": grpclib.const.Handler(
                self.__rpc_example_unary_stream,
                grpclib.const.Cardinality.UNARY_STREAM,
                ExampleRequest,
                ExampleResponse,
            ),
            "/example_service.Test/ExampleStreamUnary": grpclib.const.Handler(
                self.__rpc_example_stream_unary,
                grpclib.const.Cardinality.STREAM_UNARY,
                ExampleRequest,
                ExampleResponse,
            ),
            "/example_service.Test/ExampleStreamStream": grpclib.const.Handler(
                self.__rpc_example_stream_stream,
                grpclib.const.Cardinality.STREAM_STREAM,
                ExampleRequest,
                ExampleResponse,
            ),
        }



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof_empty.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Nothing",
    "MaybeNothing",
    "Test",
)


from typing import (
    Optional,
)

from pydantic import model_validator
from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Nothing(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class MaybeNothing(betterproto.Message):
    """ """

    sometimes: str = betterproto.string_field(42)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    nothing: Optional["Nothing"] = betterproto.message_field(
        1, optional=True, group="empty"
    )
    """
    
    """

    maybe1: Optional["MaybeNothing"] = betterproto.message_field(
        2, optional=True, group="empty"
    )
    """
    
    """

    maybe2: Optional["MaybeNothing"] = betterproto.message_field(
        3, optional=True, group="empty"
    )
    """
    
    """

    @model_validator(mode="after")
    def check_oneof(cls, values):
        return cls._validate_field_groups(values)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nested2.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'nested2.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import package_pb2 as package__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rnested2.proto\x12\x07nested2\x1a\rpackage.proto\",\n\x04Game\x1a$\n\x06Player\"\x1a\n\x04Race\x12\t\n\x05human\x10\x00\x12\x07\n\x03orc\x10\x01\"\xab\x01\n\x04Test\x12\x1b\n\x04game\x18\x01 \x01(\x0b\x32\r.nested2.Game\x12(\n\nGamePlayer\x18\x02 \x01(\x0b\x32\x14.nested2.Game.Player\x12\x31\n\x0eGamePlayerRace\x18\x03 \x01(\x0e\x32\x19.nested2.Game.Player.Race\x12)\n\x06Weapon\x18\x04 \x01(\x0b\x32\x19.nested2.equipment.Weaponb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nested2_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GAME']._serialized_start=41
  _globals['_GAME']._serialized_end=85
  _globals['_GAME_PLAYER']._serialized_start=49
  _globals['_GAME_PLAYER']._serialized_end=85
  _globals['_GAME_PLAYER_RACE']._serialized_start=59
  _globals['_GAME_PLAYER_RACE']._serialized_end=85
  _globals['_TEST']._serialized_start=88
  _globals['_TEST']._serialized_end=259
# @@protoc_insertion_point(module_scope)



import warnings

import pytest

from tests.mocks import MockChannel
from tests.output_betterproto.deprecated import (
    Empty,
    Message,
    Test,
    TestServiceStub,
)


@pytest.fixture
def message():
    with warnings.catch_warnings():
        warnings.filterwarnings("ignore", category=DeprecationWarning)
        return Message(value="hello")


def test_deprecated_message():
    with pytest.warns(DeprecationWarning) as record:
        Message(value="hello")

    assert len(record) == 1
    assert str(record[0].message) == f"{Message.__name__} is deprecated"


def test_message_with_deprecated_field(message):
    with pytest.warns(DeprecationWarning) as record:
        Test(message=message, value=10)

    assert len(record) == 1
    assert str(record[0].message) == f"{Test.__name__}.message is deprecated"


def test_message_with_deprecated_field_not_set(message):
    with warnings.catch_warnings():
        warnings.simplefilter("error")
        Test(value=10)


def test_message_with_deprecated_field_not_set_default(message):
    with warnings.catch_warnings():
        warnings.simplefilter("error")
        _ = Test(value=10).message


@pytest.mark.asyncio
async def test_service_with_deprecated_method():
    stub = TestServiceStub(MockChannel([Empty(), Empty()]))

    with pytest.warns(DeprecationWarning) as record:
        await stub.deprecated_func(Empty())

    assert len(record) == 1
    assert str(record[0].message) == f"TestService.deprecated_func is deprecated"

    with warnings.catch_warnings():
        warnings.simplefilter("error")
        await stub.func(Empty())



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: float.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """Some documentation about the Test message."""

    positive: float = betterproto_fw.double_field(1)
    """
    
    """

    negative: float = betterproto_fw.double_field(2)
    """
    
    """

    nan: float = betterproto_fw.double_field(3)
    """
    
    """

    three: float = betterproto_fw.double_field(4)
    """
    
    """

    three_point_one_four: float = betterproto_fw.double_field(5)
    """
    
    """

    neg_three: float = betterproto_fw.double_field(6)
    """
    
    """

    neg_three_point_one_four: float = betterproto_fw.double_field(7)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: test.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """
    Verify that we can import a message unrelated to us, in a subpackage with the same name as us.
    """

    message: "__cousin_subpackage__.CousinMessage" = betterproto_fw.message_field(1)
    """
    
    """


from ...cousin import subpackage as __cousin_subpackage__



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: casing.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "MyEnum",
    "Test",
    "SnakeCaseMessage",
)


from pydantic.dataclasses import dataclass

import betterproto_fw


class MyEnum(betterproto_fw.Enum):
    """ """

    ZERO = 0
    """
    
    """

    ONE = 1
    """
    
    """

    TWO = 2
    """
    
    """

    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type, _handler):
        from pydantic_core import core_schema

        return core_schema.int_schema(ge=0)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """ """

    camel_case: int = betterproto_fw.int32_field(1)
    """
    
    """

    snake_case: "MyEnum" = betterproto_fw.enum_field(2)
    """
    
    """

    snake_case_message: "SnakeCaseMessage" = betterproto_fw.message_field(3)
    """
    
    """

    uppercase: int = betterproto_fw.int32_field(4)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class SnakeCaseMessage(betterproto_fw.Message):
    """ """

    pass



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: documentation.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Enum",
    "Test",
    "ServiceStub",
    "ServiceBase",
)


from dataclasses import dataclass
from typing import (
    TYPE_CHECKING,
    Dict,
    Optional,
)

import grpclib

import betterproto
from betterproto.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto.grpc.grpclib_client import MetadataLike


class Enum(betterproto.Enum):
    """
    Documentation of enum 1
    other line 1

    Documentation of enum 2
    other line 2

    Documentation of enum 3
    """

    Enum_Variant = 0
    """
    Documentation of variant 1
    other line 1
    
    Documentation of variant 2
    other line 2
    
    Documentation of variant 3
    """


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """
    Documentation of message 1
    other line 1

    Documentation of message 2
    other line 2

    Documentation of message 3
    """

    x: int = betterproto.uint32_field(1)
    """
    Documentation of field 1
    other line 1
    
    Documentation of field 2
    other line 2
    
    Documentation of field 3
    """


class ServiceStub(betterproto.ServiceStub):
    """
    Documentation of service 1
    other line 1

    Documentation of service 2
    other line 2

    Documentation of service 3
    """

    async def get(
        self,
        test: "Test",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "Test":
        """
        Documentation of method 1
        other line 1

        Documentation of method 2
        other line 2

        Documentation of method 3
        """

        return await self._unary_unary(
            "/documentation.Service/get",
            test,
            Test,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


class ServiceBase(ServiceBase):
    """
    Documentation of service 1
    other line 1

    Documentation of service 2
    other line 2

    Documentation of service 3
    """

    async def get(self, test: "Test") -> "Test":
        """
        Documentation of method 1
        other line 1

        Documentation of method 2
        other line 2

        Documentation of method 3
        """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_get(self, stream: "grpclib.server.Stream[Test, Test]") -> None:
        request = await stream.recv_message()
        response = await self.get(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/documentation.Service/get": grpclib.const.Handler(
                self.__rpc_get,
                grpclib.const.Cardinality.UNARY_UNARY,
                Test,
                Test,
            ),
        }



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: service.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "TestStub",
    "TestBase",
)


from typing import (
    TYPE_CHECKING,
    AsyncIterable,
    AsyncIterator,
    Dict,
    Iterable,
    Optional,
    Union,
)

import grpclib

import betterproto_fw
from betterproto_fw.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto_fw.grpc.grpclib_client import MetadataLike


class TestStub(betterproto_fw.ServiceStub):
    """ """

    async def do_thing(
        self,
        messages_do_thing_request: "_messages__.DoThingRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "_messages__.DoThingResponse":
        """ """

        return await self._unary_unary(
            "/service_separate_packages.things.service.Test/DoThing",
            messages_do_thing_request,
            _messages__.DoThingResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def do_many_things(
        self,
        messages_do_thing_request_iterator: "Union[AsyncIterable[_messages__.DoThingRequest], Iterable[_messages__.DoThingRequest]]",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "_messages__.DoThingResponse":
        """ """

        return await self._stream_unary(
            "/service_separate_packages.things.service.Test/DoManyThings",
            messages_do_thing_request_iterator,
            _messages__.DoThingRequest,
            _messages__.DoThingResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_thing_versions(
        self,
        messages_get_thing_request: "_messages__.GetThingRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "AsyncIterator[_messages__.GetThingResponse]":
        """ """

        async for response in self._unary_stream(
            "/service_separate_packages.things.service.Test/GetThingVersions",
            messages_get_thing_request,
            _messages__.GetThingResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        ):
            yield response

    async def get_different_things(
        self,
        messages_get_thing_request_iterator: "Union[AsyncIterable[_messages__.GetThingRequest], Iterable[_messages__.GetThingRequest]]",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "AsyncIterator[_messages__.GetThingResponse]":
        """ """

        async for response in self._stream_stream(
            "/service_separate_packages.things.service.Test/GetDifferentThings",
            messages_get_thing_request_iterator,
            _messages__.GetThingRequest,
            _messages__.GetThingResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        ):
            yield response


from .. import messages as _messages__


class TestBase(ServiceBase):
    """ """

    async def do_thing(
        self, messages_do_thing_request: "_messages__.DoThingRequest"
    ) -> "_messages__.DoThingResponse":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def do_many_things(
        self,
        messages_do_thing_request_iterator: AsyncIterator[_messages__.DoThingRequest],
    ) -> "_messages__.DoThingResponse":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_thing_versions(
        self, messages_get_thing_request: "_messages__.GetThingRequest"
    ) -> AsyncIterator[_messages__.GetThingResponse]:
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)
        yield _messages__.GetThingResponse()

    async def get_different_things(
        self,
        messages_get_thing_request_iterator: AsyncIterator[_messages__.GetThingRequest],
    ) -> AsyncIterator[_messages__.GetThingResponse]:
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)
        yield _messages__.GetThingResponse()

    async def __rpc_do_thing(
        self,
        stream: "grpclib.server.Stream[_messages__.DoThingRequest, _messages__.DoThingResponse]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.do_thing(request)
        await stream.send_message(response)

    async def __rpc_do_many_things(
        self,
        stream: "grpclib.server.Stream[_messages__.DoThingRequest, _messages__.DoThingResponse]",
    ) -> None:
        request = stream.__aiter__()
        response = await self.do_many_things(request)
        await stream.send_message(response)

    async def __rpc_get_thing_versions(
        self,
        stream: "grpclib.server.Stream[_messages__.GetThingRequest, _messages__.GetThingResponse]",
    ) -> None:
        request = await stream.recv_message()
        await self._call_rpc_handler_server_stream(
            self.get_thing_versions,
            stream,
            request,
        )

    async def __rpc_get_different_things(
        self,
        stream: "grpclib.server.Stream[_messages__.GetThingRequest, _messages__.GetThingResponse]",
    ) -> None:
        request = stream.__aiter__()
        await self._call_rpc_handler_server_stream(
            self.get_different_things,
            stream,
            request,
        )

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/service_separate_packages.things.service.Test/DoThing": grpclib.const.Handler(
                self.__rpc_do_thing,
                grpclib.const.Cardinality.UNARY_UNARY,
                _messages__.DoThingRequest,
                _messages__.DoThingResponse,
            ),
            "/service_separate_packages.things.service.Test/DoManyThings": grpclib.const.Handler(
                self.__rpc_do_many_things,
                grpclib.const.Cardinality.STREAM_UNARY,
                _messages__.DoThingRequest,
                _messages__.DoThingResponse,
            ),
            "/service_separate_packages.things.service.Test/GetThingVersions": grpclib.const.Handler(
                self.__rpc_get_thing_versions,
                grpclib.const.Cardinality.UNARY_STREAM,
                _messages__.GetThingRequest,
                _messages__.GetThingResponse,
            ),
            "/service_separate_packages.things.service.Test/GetDifferentThings": grpclib.const.Handler(
                self.__rpc_get_different_things,
                grpclib.const.Cardinality.STREAM_STREAM,
                _messages__.GetThingRequest,
                _messages__.GetThingResponse,
            ),
        }



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: enum.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nenum.proto\x12\x04\x65num\"C\n\x04Test\x12\x1c\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x0c.enum.Choice\x12\x1d\n\x07\x63hoices\x18\x02 \x03(\x0e\x32\x0c.enum.Choice*0\n\x06\x43hoice\x12\x08\n\x04ZERO\x10\x00\x12\x07\n\x03ONE\x10\x01\x12\x08\n\x04\x46OUR\x10\x04\x12\t\n\x05THREE\x10\x03*\x93\x01\n\x12\x41rithmeticOperator\x12\x1c\n\x18\x41RITHMETIC_OPERATOR_NONE\x10\x00\x12\x1c\n\x18\x41RITHMETIC_OPERATOR_PLUS\x10\x01\x12\x1d\n\x19\x41RITHMETIC_OPERATOR_MINUS\x10\x02\x12\"\n\x1e\x41RITHMETIC_OPERATOR_0_PREFIXED\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHOICE']._serialized_start=89
  _globals['_CHOICE']._serialized_end=137
  _globals['_ARITHMETICOPERATOR']._serialized_start=140
  _globals['_ARITHMETICOPERATOR']._serialized_end=287
  _globals['_TEST']._serialized_start=20
  _globals['_TEST']._serialized_end=87
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: service.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "ThingType",
    "DoThingRequest",
    "DoThingResponse",
    "GetThingRequest",
    "GetThingResponse",
    "TestStub",
    "TestBase",
)


from typing import (
    TYPE_CHECKING,
    AsyncIterable,
    AsyncIterator,
    Dict,
    Iterable,
    List,
    Optional,
    Union,
)

import grpclib
from pydantic.dataclasses import dataclass

import betterproto_fw
from betterproto_fw.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto_fw.grpc.grpclib_client import MetadataLike


class ThingType(betterproto_fw.Enum):
    """ """

    UNKNOWN = 0
    """
    
    """

    LIVING = 1
    """
    
    """

    DEAD = 2
    """
    
    """

    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type, _handler):
        from pydantic_core import core_schema

        return core_schema.int_schema(ge=0)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class DoThingRequest(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """

    comments: List[str] = betterproto_fw.string_field(2)
    """
    
    """

    type: "ThingType" = betterproto_fw.enum_field(3)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class DoThingResponse(betterproto_fw.Message):
    """ """

    names: List[str] = betterproto_fw.string_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class GetThingRequest(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class GetThingResponse(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """

    version: int = betterproto_fw.int32_field(2)
    """
    
    """


class TestStub(betterproto_fw.ServiceStub):
    """ """

    async def do_thing(
        self,
        do_thing_request: "DoThingRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "DoThingResponse":
        """ """

        return await self._unary_unary(
            "/service.Test/DoThing",
            do_thing_request,
            DoThingResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def do_many_things(
        self,
        do_thing_request_iterator: "Union[AsyncIterable[DoThingRequest], Iterable[DoThingRequest]]",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "DoThingResponse":
        """ """

        return await self._stream_unary(
            "/service.Test/DoManyThings",
            do_thing_request_iterator,
            DoThingRequest,
            DoThingResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )

    async def get_thing_versions(
        self,
        get_thing_request: "GetThingRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "AsyncIterator[GetThingResponse]":
        """ """

        async for response in self._unary_stream(
            "/service.Test/GetThingVersions",
            get_thing_request,
            GetThingResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        ):
            yield response

    async def get_different_things(
        self,
        get_thing_request_iterator: "Union[AsyncIterable[GetThingRequest], Iterable[GetThingRequest]]",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "AsyncIterator[GetThingResponse]":
        """ """

        async for response in self._stream_stream(
            "/service.Test/GetDifferentThings",
            get_thing_request_iterator,
            GetThingRequest,
            GetThingResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        ):
            yield response


class TestBase(ServiceBase):
    """ """

    async def do_thing(self, do_thing_request: "DoThingRequest") -> "DoThingResponse":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def do_many_things(
        self, do_thing_request_iterator: AsyncIterator[DoThingRequest]
    ) -> "DoThingResponse":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def get_thing_versions(
        self, get_thing_request: "GetThingRequest"
    ) -> AsyncIterator[GetThingResponse]:
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)
        yield GetThingResponse()

    async def get_different_things(
        self, get_thing_request_iterator: AsyncIterator[GetThingRequest]
    ) -> AsyncIterator[GetThingResponse]:
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)
        yield GetThingResponse()

    async def __rpc_do_thing(
        self, stream: "grpclib.server.Stream[DoThingRequest, DoThingResponse]"
    ) -> None:
        request = await stream.recv_message()
        response = await self.do_thing(request)
        await stream.send_message(response)

    async def __rpc_do_many_things(
        self, stream: "grpclib.server.Stream[DoThingRequest, DoThingResponse]"
    ) -> None:
        request = stream.__aiter__()
        response = await self.do_many_things(request)
        await stream.send_message(response)

    async def __rpc_get_thing_versions(
        self, stream: "grpclib.server.Stream[GetThingRequest, GetThingResponse]"
    ) -> None:
        request = await stream.recv_message()
        await self._call_rpc_handler_server_stream(
            self.get_thing_versions,
            stream,
            request,
        )

    async def __rpc_get_different_things(
        self, stream: "grpclib.server.Stream[GetThingRequest, GetThingResponse]"
    ) -> None:
        request = stream.__aiter__()
        await self._call_rpc_handler_server_stream(
            self.get_different_things,
            stream,
            request,
        )

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/service.Test/DoThing": grpclib.const.Handler(
                self.__rpc_do_thing,
                grpclib.const.Cardinality.UNARY_UNARY,
                DoThingRequest,
                DoThingResponse,
            ),
            "/service.Test/DoManyThings": grpclib.const.Handler(
                self.__rpc_do_many_things,
                grpclib.const.Cardinality.STREAM_UNARY,
                DoThingRequest,
                DoThingResponse,
            ),
            "/service.Test/GetThingVersions": grpclib.const.Handler(
                self.__rpc_get_thing_versions,
                grpclib.const.Cardinality.UNARY_STREAM,
                GetThingRequest,
                GetThingResponse,
            ),
            "/service.Test/GetDifferentThings": grpclib.const.Handler(
                self.__rpc_get_different_things,
                grpclib.const.Cardinality.STREAM_STREAM,
                GetThingRequest,
                GetThingResponse,
            ),
        }



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_packages_same_name.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """
    Tests generated message can correctly reference two packages with the same leaf-name
    """

    user: "users_v1.User" = betterproto_fw.message_field(1)
    """
    
    """

    post: "posts_v1.Post" = betterproto_fw.message_field(2)
    """
    
    """


from .posts import v1 as posts_v1
from .users import v1 as users_v1



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: messages.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "DoThingRequest",
    "DoThingResponse",
    "GetThingRequest",
    "GetThingResponse",
)


from datetime import datetime, timedelta
from typing import (
    List,
)

from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class DoThingRequest(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """

    comments: List[str] = betterproto_fw.string_field(2)
    """use `repeated` so we can check if `List` is correctly imported"""

    when: datetime = betterproto_fw.message_field(3)
    """
    use google types `timestamp` and `duration` so we can check
    if everything from `datetime` is correctly imported
    """

    duration: timedelta = betterproto_fw.message_field(4)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class DoThingResponse(betterproto_fw.Message):
    """ """

    names: List[str] = betterproto_fw.string_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class GetThingRequest(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class GetThingResponse(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """

    version: int = betterproto_fw.int32_field(2)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes_service_returns_empty.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "RequestMessage",
    "TestStub",
    "TestBase",
)


from dataclasses import dataclass
from typing import (
    TYPE_CHECKING,
    Dict,
    Optional,
)

import grpclib

import betterproto_fw
from betterproto_fw.grpc.grpclib_server import ServiceBase


if TYPE_CHECKING:
    import grpclib.server
    from grpclib.metadata import Deadline

    from betterproto_fw.grpc.grpclib_client import MetadataLike


@dataclass(eq=False, repr=False)
class RequestMessage(betterproto_fw.Message):
    """ """

    pass


class TestStub(betterproto_fw.ServiceStub):
    """ """

    async def send(
        self,
        request_message: "RequestMessage",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None,
    ) -> "betterproto_fw_lib_google_protobuf.Empty":
        """ """

        return await self._unary_unary(
            "/googletypes_service_returns_empty.Test/Send",
            request_message,
            betterproto_fw_lib_google_protobuf.Empty,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        )


import betterproto_fw.lib.google.protobuf as betterproto_fw_lib_google_protobuf


class TestBase(ServiceBase):
    """ """

    async def send(
        self, request_message: "RequestMessage"
    ) -> "betterproto_fw_lib_google_protobuf.Empty":
        """ """

        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_send(
        self,
        stream: "grpclib.server.Stream[RequestMessage, betterproto_fw_lib_google_protobuf.Empty]",
    ) -> None:
        request = await stream.recv_message()
        response = await self.send(request)
        await stream.send_message(response)

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/googletypes_service_returns_empty.Test/Send": grpclib.const.Handler(
                self.__rpc_send,
                grpclib.const.Cardinality.UNARY_UNARY,
                RequestMessage,
                betterproto_fw_lib_google_protobuf.Empty,
            ),
        }



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: googletypes_request.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'googletypes_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19googletypes_request.proto\x12\x13googletypes_request\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x07\n\x05Input2\xd3\x06\n\x04Test\x12\x46\n\nSendDouble\x12\x1c.google.protobuf.DoubleValue\x1a\x1a.googletypes_request.Input\x12\x44\n\tSendFloat\x12\x1b.google.protobuf.FloatValue\x1a\x1a.googletypes_request.Input\x12\x44\n\tSendInt64\x12\x1b.google.protobuf.Int64Value\x1a\x1a.googletypes_request.Input\x12\x46\n\nSendUInt64\x12\x1c.google.protobuf.UInt64Value\x1a\x1a.googletypes_request.Input\x12\x44\n\tSendInt32\x12\x1b.google.protobuf.Int32Value\x1a\x1a.googletypes_request.Input\x12\x46\n\nSendUInt32\x12\x1c.google.protobuf.UInt32Value\x1a\x1a.googletypes_request.Input\x12\x42\n\x08SendBool\x12\x1a.google.protobuf.BoolValue\x1a\x1a.googletypes_request.Input\x12\x46\n\nSendString\x12\x1c.google.protobuf.StringValue\x1a\x1a.googletypes_request.Input\x12\x44\n\tSendBytes\x12\x1b.google.protobuf.BytesValue\x1a\x1a.googletypes_request.Input\x12\x46\n\x0cSendDatetime\x12\x1a.google.protobuf.Timestamp\x1a\x1a.googletypes_request.Input\x12\x46\n\rSendTimedelta\x12\x19.google.protobuf.Duration\x1a\x1a.googletypes_request.Input\x12?\n\tSendEmpty\x12\x16.google.protobuf.Empty\x1a\x1a.googletypes_request.Inputb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'googletypes_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INPUT']._serialized_start=176
  _globals['_INPUT']._serialized_end=183
  _globals['_TEST']._serialized_start=186
  _globals['_TEST']._serialized_end=1037
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12\x11service_uppercase\"0\n\x0e\x44oTHINGRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63omments\x18\x02 \x03(\t\" \n\x0f\x44oTHINGResponse\x12\r\n\x05names\x18\x01 \x03(\t2X\n\x04Test\x12P\n\x07\x44oThing\x12!.service_uppercase.DoTHINGRequest\x1a\".service_uppercase.DoTHINGResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DOTHINGREQUEST']._serialized_start=36
  _globals['_DOTHINGREQUEST']._serialized_end=84
  _globals['_DOTHINGRESPONSE']._serialized_start=86
  _globals['_DOTHINGRESPONSE']._serialized_end=118
  _globals['_TEST']._serialized_start=120
  _globals['_TEST']._serialized_end=208
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: float.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'float.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x66loat.proto\x12\x05\x66loat\"\x99\x01\n\x04Test\x12\x10\n\x08positive\x18\x01 \x01(\x01\x12\x10\n\x08negative\x18\x02 \x01(\x01\x12\x0b\n\x03nan\x18\x03 \x01(\x01\x12\r\n\x05three\x18\x04 \x01(\x01\x12\x1c\n\x14three_point_one_four\x18\x05 \x01(\x01\x12\x11\n\tneg_three\x18\x06 \x01(\x01\x12 \n\x18neg_three_point_one_four\x18\x07 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'float_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=23
  _globals['_TEST']._serialized_end=176
# @@protoc_insertion_point(module_scope)



import pytest


def test_invalid_field():
    from tests.output_betterproto.invalid_field import Test

    with pytest.raises(TypeError):
        Test(unknown_field=12)


def test_invalid_field_pydantic():
    from pydantic import ValidationError

    from tests.output_betterproto_pydantic.invalid_field import Test

    with pytest.raises(ValidationError):
        Test(unknown_field=12)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof_enum.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Signal",
    "Test",
    "Move",
)


from dataclasses import dataclass

import betterproto


class Signal(betterproto.Enum):
    """ """

    PASS = 0
    """
    
    """

    RESIGN = 1
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    signal: "Signal" = betterproto.enum_field(1, group="action")
    """
    
    """

    move: "Move" = betterproto.message_field(2, group="action")
    """
    
    """


@dataclass(eq=False, repr=False)
class Move(betterproto.Message):
    """ """

    x: int = betterproto.int32_field(1)
    """
    
    """

    y: int = betterproto.int32_field(2)
    """
    
    """



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: repeatedmessage.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "Sub",
)


from typing import (
    List,
)

from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    greetings: List["Sub"] = betterproto.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Sub(betterproto.Message):
    """ """

    greeting: str = betterproto.string_field(1)
    """
    
    """
